@@ -1,19 +1,15 @@
 require 'spec_helper'
 
 describe 'gnocchi::client' do
-
-  shared_examples_for 'gnocchi client' do
-
+  shared_examples 'gnocchi::client' do
     it { is_expected.to contain_class('gnocchi::deps') }
     it { is_expected.to contain_class('gnocchi::params') }
 
-    it 'installs gnocchi client package' do
-      is_expected.to contain_package('python-gnocchiclient').with(
-        :ensure => 'present',
-        :name   => platform_params[:client_package_name],
-        :tag    => 'openstack',
-      )
-    end
+    it { should contain_package('python-gnocchiclient').with(
+      :ensure => 'present',
+      :name   => platform_params[:client_package_name],
+      :tag    => 'openstack',
+    )}
   end
 
   on_supported_os({
@@ -27,18 +23,13 @@ describe 'gnocchi::client' do
       let(:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          if facts[:os_package_type] == 'debian'
-            { :client_package_name => 'python3-gnocchiclient' }
-          else
-            { :client_package_name => 'python-gnocchiclient' }
-          end
+          { :client_package_name => 'python3-gnocchiclient' }
         when 'RedHat'
           { :client_package_name => 'python-gnocchiclient' }
         end
       end
 
-      it_behaves_like 'gnocchi client'
+      it_behaves_like 'gnocchi::client'
     end
   end
-
 end
